@@ -1,20 +1,22 @@
 #include "aboutdialog.h"
-#include "ui_aboutdialog.h"
-#include "build_number.h"
-#include "version.h"
-#include "release.h"
-#include <QFile>
-#include <QDate>
-#include <QTextStream>
+
 #include <utils/misc.h>
 
-AboutDialog::AboutDialog(QWidget *parent) :
-        MasterDialog(parent),
-        ui(new Ui::AboutDialog) {
+#include <QDate>
+#include <QFile>
+#include <QTextStream>
+
+#include "build_number.h"
+#include "release.h"
+#include "ui_aboutdialog.h"
+#include "version.h"
+
+AboutDialog::AboutDialog(QWidget *parent)
+    : MasterDialog(parent), ui(new Ui::AboutDialog) {
     ui->setupUi(this);
 
     // load the about.html
-    QFile f(":/html/about.html");
+    QFile f(QStringLiteral(":/html/about.html"));
     if (f.open(QFile::ReadOnly | QFile::Text)) {
         QTextStream istream(&f);
         QString html = istream.readAll();
@@ -22,19 +24,21 @@ AboutDialog::AboutDialog(QWidget *parent) :
 
         QString release = qApp->property("release").toString();
         if (release.isEmpty()) {
-            release = "generic";
+            release = QLatin1String("generic");
         }
 
         // fill in the variables
-        html.replace("QT_VERSION_STR", QString(QT_VERSION_STR));
-        html.replace("BUILD_NUMBER", QString::number(BUILD));
-        html.replace("BUILD_DATE", __DATE__);
-        html.replace("VERSION", QString(VERSION));
-        html.replace("RELEASE", release);
-        html.replace("CURRENT_YEAR", QString::number(date.year()));
+        html.replace(QLatin1String("QT_VERSION_STR"),
+                     QStringLiteral(QT_VERSION_STR));
+        html.replace(QLatin1String("BUILD_NUMBER"), QString::number(BUILD));
+        html.replace(QLatin1String("BUILD_DATE"), __DATE__);
+        html.replace(QLatin1String("VERSION"), QStringLiteral(VERSION));
+        html.replace(QLatin1String("RELEASE"), release);
+        html.replace(QLatin1String("CURRENT_YEAR"),
+                     QString::number(date.year()));
 
         ui->textBrowser->document()->setDefaultStyleSheet(
-                Utils::Misc::genericCSS());
+            Utils::Misc::genericCSS());
 
         // put the html to the text browser in the about dialog
         ui->textBrowser->setHtml(html);
@@ -42,6 +46,4 @@ AboutDialog::AboutDialog(QWidget *parent) :
     }
 }
 
-AboutDialog::~AboutDialog() {
-    delete ui;
-}
+AboutDialog::~AboutDialog() { delete ui; }
