@@ -24,12 +24,12 @@ class ActionDialog : public MasterDialog {
     void on_actionLineEdit_textChanged(const QString &arg1);
 
    protected:
-    bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
    private:
     Ui::ActionDialog *ui;
     QMenuBar *_menuBar;
 
     void buildActionTreeForMenu(QMenu *menu,
-                                QTreeWidgetItem *parentItem = Q_NULLPTR);
+                                QTreeWidgetItem *parentItem = nullptr);
 };
