@@ -32,7 +32,7 @@ void CodeToHtmlConverter::initCodeLangs() Q_DECL_NOTHROW {
         {QStringLiteral("html"), CodeToHtmlConverter::CodeXML},
         {QStringLiteral("ini"), CodeToHtmlConverter::CodeINI},
         {QStringLiteral("java"), CodeToHtmlConverter::CodeJava},
-        {QStringLiteral("javascript"), CodeToHtmlConverter::CodeJava},
+        {QStringLiteral("javascript"), CodeToHtmlConverter::CodeJs},
         {QStringLiteral("js"), CodeToHtmlConverter::CodeJs},
         {QStringLiteral("json"), CodeToHtmlConverter::CodeJSON},
         {QStringLiteral("make"), CodeToHtmlConverter::CodeMake},
@@ -362,13 +362,11 @@ int CodeToHtmlConverter::highlightStringLiterals(StringView input,
                                                  int i) {
     int start = i;
     ++i;
-    bool foundEnd = false;
 
     while (i < input.length()) {
         // look for string end
         // make sure it's not an escape seq
         if (input.at(i) == strType && input.at(i - 1) != '\\') {
-            foundEnd = true;
             ++i;
             break;
         }
