@@ -1,7 +1,9 @@
 #pragma once
 
 #include <QString>
-#include <QToolBar>
+#include <QStringList>
+class QToolBar;
+class QMainWindow;
 
 /**
  *  This class holds a string definition of toolbars and actions
@@ -14,11 +16,11 @@ struct ToolbarContainer {
     QStringList actions;
 
     ToolbarContainer() {}
-    ToolbarContainer(QString name, QString title, QStringList actions):
-        name(name), title(title), actions(actions)
-    {}
-    ToolbarContainer(QToolBar* toolbar);
-    QToolBar *create(QMainWindow* w) const;
+    ToolbarContainer(const QString &name, const QString &title,
+                     const QStringList &actions)
+        : name(name), title(title), actions(actions) {}
+    ToolbarContainer(QToolBar *toolbar);
+    QToolBar *create(QMainWindow *w) const;
 
     void updateToolbar();
 
