@@ -581,7 +581,7 @@ void MarkdownHighlighter::highlightHeadline(const QString &text) {
     };
 
     // take care of ==== and ---- headlines
-    const QString &prev = currentBlock().previous().text();
+    const QString prev = currentBlock().previous().text();
     auto prevSpaces = getIndentation(prev);
 
     if (text.at(spacesOffset) == QLatin1Char('=') && prevSpaces < 4) {
@@ -600,7 +600,7 @@ void MarkdownHighlighter::highlightHeadline(const QString &text) {
         }
     }
 
-    const QString &nextBlockText = currentBlock().next().text();
+    const QString nextBlockText = currentBlock().next().text();
     if (nextBlockText.isEmpty()) return;
     const int nextSpaces = getIndentation(nextBlockText);
 
@@ -905,8 +905,8 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
             comment = QLatin1Char('#');
             break;
         default:
-            comment = QChar('\0');
-            break;
+            setFormat(0, textLen, _formats[CodeBlock]);
+            return;
     }
 
     // apply the default code block format first
@@ -918,8 +918,9 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
         // check if we are at the beginning OR if this is the start of a word
         if (i == 0 || (!text.at(i - 1).isLetterOrNumber() &&
                        text.at(i-1) != QLatin1Char('_'))) {
-            auto it = data.find(text.at(i).toLatin1());
-            for (; it != data.end() && it.key() == text.at(i).toLatin1(); ++it) {
+            const char c = text.at(i).toLatin1();
+            auto it = data.find(c);
+            for (; it != data.end() && it.key() == c; ++it) {
                 // we have a word match check
                 // 1. if we are at the end
                 // 2. if we have a complete word
@@ -1032,8 +1033,9 @@ void MarkdownHighlighter::highlightSyntax(const QString &text) {
 
         /* Highlight other stuff (preprocessor etc.) */
         if (i == 0 || !text.at(i - 1).isLetter()) {
-            auto it = others.find(text.at(i).toLatin1());
-            for (; it != others.end() && it.key() == text.at(i).toLatin1(); ++it) {
+            const char c = text.at(i).toLatin1();
+            auto it = others.find(c);
+            for (; it != others.end() && it.key() == c; ++it) {
                 const QLatin1String &word = it.value();
                 if (word == MH_SUBSTR(i, word.size()) &&
                     (i + word.size() == text.length() ||
@@ -1924,7 +1926,7 @@ void MarkdownHighlighter::highlightAdditionalRules(
  */
 int isInLinkRange(int pos, QVector<QPair<int, int>> &range) {
     int j = 0;
-    for (const auto i : range) {
+    for (const auto &i : range) {
         if (pos >= i.first && pos <= i.second) {
             // return the length of the range so that we can skip it
             const int len = i.second - i.first;
@@ -2100,7 +2102,7 @@ inline bool isMDAsciiPunct(const int ch) noexcept {
 /**
  * @brief scans a chain of '*' or '_'
  * @param text: current text block
- * @param start: current position in the the text
+ * @param start: current position in the text
  * @param canSplitWord: is Underscore
  * @return length, canOpen, canClose
  * @details Helper function for Em and strong highlighting
