@@ -91,6 +91,12 @@ QMarkdownTextEdit::QMarkdownTextEdit(QWidget *parent, bool initHighlighter)
     });
     connect(this, &QPlainTextEdit::cursorPositionChanged, this, [this]() {
         _lineNumArea->update();
+
+        auto oldArea = blockBoundingGeometry(_textCursor.block()).translated(contentOffset());
+        _textCursor = textCursor();
+        auto newArea = blockBoundingGeometry(_textCursor.block()).translated(contentOffset());
+        auto areaToUpdate = oldArea | newArea;
+        viewport()->update(areaToUpdate.toRect());
     });
     connect(document(), &QTextDocument::blockCountChanged,
             this, &QMarkdownTextEdit::updateLineNumberAreaWidth);
@@ -117,6 +123,26 @@ void QMarkdownTextEdit::setSearchWidgetDebounceDelay(uint debounceDelay)
     searchWidget()->setDebounceDelay(_debounceDelay);
 }
 
+void QMarkdownTextEdit::setHighlightCurrentLine(bool set)
+{
+    _highlightCurrentLine = set;
+}
+
+bool QMarkdownTextEdit::highlightCurrentLine()
+{
+    return _highlightCurrentLine;
+}
+
+void QMarkdownTextEdit::setCurrentLineHighlightColor(const QColor &color)
+{
+    _currentLineHighlightColor = color;
+}
+
+QColor QMarkdownTextEdit::currentLineHighlightColor()
+{
+    return _currentLineHighlightColor;
+}
+
 /**
  * Enables or disables the markdown highlighting
  *
@@ -783,7 +809,7 @@ bool QMarkdownTextEdit::quotationMarkCheck(const QChar quotationCharacter) {
     const int positionInBlock = cursor.positionInBlock();
 
     // get the current text from the block
-    const QString &text = cursor.block().text();
+    const QString text = cursor.block().text();
     const int textLength = text.length();
 
     // if last char is not space, we are at word end, no autocompletion
@@ -993,6 +1019,14 @@ bool QMarkdownTextEdit::increaseSelectedTextIndention(
     QString selectedText = cursor.selectedText();
 
     if (!selectedText.isEmpty()) {
+        // Start the selection at start of the first block of the selection
+        int end = cursor.selectionEnd();
+        cursor.setPosition(cursor.selectionStart());
+        cursor.movePosition(QTextCursor::StartOfBlock, QTextCursor::MoveAnchor);
+        cursor.setPosition(end, QTextCursor::KeepAnchor);
+        this->setTextCursor(cursor);
+        selectedText = cursor.selectedText();
+
         // we need this strange newline character we are getting in the
         // selected text for newlines
         const QString newLine =
@@ -1570,7 +1604,7 @@ bool QMarkdownTextEdit::handleTabEntered(bool reverse,
         }
     }
 
-    // check if we want to intent the whole text
+    // check if we want to indent the whole text
     return increaseSelectedTextIndention(reverse, indentCharacters);
 }
 
@@ -1737,6 +1771,17 @@ void QMarkdownTextEdit::paintEvent(QPaintEvent *e) {
             layout->setTextOption(opt);
         }
 
+        // Current line highlight
+        QTextCursor cursor = textCursor();
+        if (highlightCurrentLine() && cursor.block() == block) {
+            QTextLine line = block.layout()->lineForTextPosition(cursor.positionInBlock());
+            QRectF lineRect = line.rect();
+            lineRect.moveTop(lineRect.top() + r.top());
+            lineRect.setLeft(0.);
+            lineRect.setRight(viewportRect.width());
+            painter.fillRect(lineRect.toAlignedRect(), currentLineHighlightColor());
+        }
+
         block = block.next();
         firstVisible = false;
     }
@@ -1786,10 +1831,5 @@ void QMarkdownTextEdit::setLineNumberLeftMarginOffset(int offset) {
 }
 
 QMargins QMarkdownTextEdit::viewportMargins() {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     return QPlainTextEdit::viewportMargins();
-#else
-    // This most likely will break line numbers, they aren't really supported in Qt < 5.5
-    return QMargins();
-#endif
 }
