@@ -114,8 +114,8 @@ bool QPlainTextEditSearchWidget::eventFilter(QObject *obj, QEvent *event) {
         if (keyEvent->key() == Qt::Key_Escape) {
             deactivate();
             return true;
-        } else if (!_debounceTimer.isActive() &&
-                    (keyEvent->modifiers().testFlag(Qt::ShiftModifier) &&
+        } else if ((!_debounceTimer.isActive() &&
+                    keyEvent->modifiers().testFlag(Qt::ShiftModifier) &&
                     (keyEvent->key() == Qt::Key_Return)) ||
                     (keyEvent->key() == Qt::Key_Up)) {
             doSearchUp();
