@@ -84,6 +84,8 @@ class MainWindow : public QMainWindow {
     Q_PROPERTY(Note currentNote WRITE setCurrentNote MEMBER currentNote NOTIFY
                    currentNoteChanged)
 
+    friend struct FileWatchDisabler;
+
    Q_SIGNALS:
     void currentNoteChanged(Note &note);
     void log(LogWidget::LogType logType, QString text);
@@ -188,6 +190,8 @@ class MainWindow : public QMainWindow {
 
     bool jumpToNoteSubFolder(int noteSubFolderId);
 
+    void selectNavigationItemAtPosition(int position);
+
     Q_INVOKABLE bool createNewNoteSubFolder(QString folderName = QString());
 
     QString getLogText();
@@ -230,6 +234,8 @@ class MainWindow : public QMainWindow {
 
     void regenerateNotePreview();
 
+    void forceRegenerateNotePreview();
+
     void storeUpdatedNotesToDisk();
 
     void changeNoteFolder(const int noteFolderId,
@@ -671,6 +677,8 @@ class MainWindow : public QMainWindow {
 
     void on_actionImport_notes_from_Joplin_triggered();
 
+    void on_actionToggle_Always_on_top_triggered();
+
 public:
     /** Settings access **/
     static bool isInDistractionFreeMode();
@@ -757,6 +765,7 @@ private:
     QDockWidget *_notePreviewDockWidget;
     QDockWidget *_logDockWidget;
     QDockWidget *_scriptingDockWidget;
+    class LogWidget *_logWidget;
     QWidget *_taggingDockTitleBarWidget;
     QWidget *_noteSubFolderDockTitleBarWidget;
     QWidget *_noteSearchDockTitleBarWidget;
@@ -806,6 +815,8 @@ private:
 
     void initNotePreviewAndTextEdits();
 
+    void connectFileWatcher(bool delayed = false);
+
     void createSystemTrayIcon();
 
     void loadNoteDirectoryList();
@@ -1065,8 +1076,6 @@ private:
 
     void centerAndResize();
 
-    void forceRegenerateNotePreview();
-
     void removeConflictedNotesDatabaseCopies();
 
     void insertNoteText(const QString &text);
