@@ -15,6 +15,12 @@
 #include <QFileDialog>
 #include <QFileInfo>
 #include <QMimeData>
+
+#ifdef __GNUC__
+    #if __GNUC__ >= 11
+        QT_WARNING_DISABLE_GCC("-Wmismatched-new-delete")
+    #endif
+#endif
 #include <QQmlComponent>
 #include <QQmlContext>
 #include <QQmlEngine>
@@ -40,8 +46,6 @@
 #include "widgets/qownnotesmarkdowntextedit.h"
 #endif
 
-static bool _componentsInitialized = false;
-
 ScriptingService::ScriptingService(QObject *parent) : QObject(parent) {
     _engine = new QQmlEngine(this);
     _engine->rootContext()->setContextProperty(QStringLiteral("script"), this);
@@ -83,10 +87,6 @@ ScriptingService *ScriptingService::instance() {
     if (scriptingService == nullptr) {
         scriptingService = createInstance(nullptr);
     }
-    if (!_componentsInitialized) {
-        scriptingService->initComponents();
-        _componentsInitialized = true;
-    }
 
     return scriptingService;
 }
@@ -231,7 +231,7 @@ void ScriptingService::reloadScriptComponents() {
 #ifndef INTEGRATION_TESTS
     // do some things in the main window (like clearing the custom actions)
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         mainWindow->preReloadScriptingEngine();
     }
 #endif
@@ -297,6 +297,7 @@ void ScriptingService::initComponents() {
     clearCustomStyleSheets();
     _scriptComponents.clear();
     _settingsVariables.clear();
+    _highlightingRules.clear();
 
     // fetch enabled only
     const QList<Script> scripts = Script::fetchAll(true);
@@ -1137,7 +1138,7 @@ void ScriptingService::callCustomActionInvokedForObject(
 /**
  * QML wrapper to get the current note
  *
- * @return {NoteApi} the the current note
+ * @return {NoteApi} the current note
  */
 NoteApi *ScriptingService::currentNote() const {
     MetricsService::instance()->sendVisitIfEnabled(
@@ -1157,7 +1158,7 @@ void ScriptingService::noteTextEditWrite(const QString &text) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         mainWindow->writeToNoteTextEdit(text);
     }
 #else
@@ -1176,7 +1177,7 @@ QString ScriptingService::noteTextEditSelectedText() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    return mainWindow != Q_NULLPTR ? mainWindow->selectedNoteTextEditText()
+    return mainWindow != nullptr ? mainWindow->selectedNoteTextEditText()
                                    : QString();
 #else
     return QString();
@@ -1192,7 +1193,7 @@ void ScriptingService::noteTextEditSelectAll() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         mainWindow->activeNoteTextEdit()->selectAll();
     }
 #endif
@@ -1207,7 +1208,7 @@ void ScriptingService::noteTextEditSelectCurrentLine() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         QTextCursor c = textEdit->textCursor();
         c.movePosition(QTextCursor::StartOfBlock);
@@ -1226,7 +1227,7 @@ void ScriptingService::noteTextEditSelectCurrentWord() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         QTextCursor c = textEdit->textCursor();
         c.select(QTextCursor::WordUnderCursor);
@@ -1247,12 +1248,12 @@ void ScriptingService::noteTextEditSetSelection(int start, int end) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         QTextCursor c = textEdit->textCursor();
 
-        start = std::max(start, 0);
-        end = std::min(end, textEdit->toPlainText().count());
+        start = std::max<int>(start, 0);
+        end = std::min<int>(end, textEdit->toPlainText().count());
 
         c.setPosition(start);
         c.setPosition(end, QTextCursor::KeepAnchor);
@@ -1277,9 +1278,9 @@ void ScriptingService::noteTextEditSetCursorPosition(int position) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
-        position = std::min(position, textEdit->toPlainText().count());
+        position = std::min<int>(position, textEdit->toPlainText().count());
         QTextCursor c = textEdit->textCursor();
 
         if (position < 0) {
@@ -1305,7 +1306,7 @@ int ScriptingService::noteTextEditCursorPosition() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         QTextCursor c = textEdit->textCursor();
 
@@ -1325,7 +1326,7 @@ int ScriptingService::noteTextEditSelectionStart() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         return textEdit->textCursor().selectionStart();
     }
@@ -1343,7 +1344,7 @@ int ScriptingService::noteTextEditSelectionEnd() {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QOwnNotesMarkdownTextEdit *textEdit = mainWindow->activeNoteTextEdit();
         return textEdit->textCursor().selectionEnd();
     }
@@ -1366,7 +1367,7 @@ QString ScriptingService::noteTextEditCurrentWord(bool withPreviousCharacters) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    return mainWindow != Q_NULLPTR
+    return mainWindow != nullptr
                ? mainWindow->activeNoteTextEdit()->currentWord(withPreviousCharacters)
                : QString();
 #else
@@ -1386,7 +1387,7 @@ void ScriptingService::tagCurrentNote(const QString &tagName) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         mainWindow->linkTagNameToCurrentNote(tagName);
     }
 #else
@@ -1406,7 +1407,7 @@ void ScriptingService::log(QString text) {
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         emit mainWindow->log(LogWidget::ScriptingLogType, std::move(text));
     }
 #else
@@ -1502,11 +1503,12 @@ void ScriptingService::regenerateNotePreview() const {
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         MetricsService::instance()->sendVisitIfEnabled(
             QStringLiteral("scripting/") % QString(__func__));
 
-        mainWindow->regenerateNotePreview();
+        // Also regenerate the note preview if the note wasn't changed to e.g. reload images
+        mainWindow->forceRegenerateNotePreview();
     }
 #endif
 }
@@ -1538,7 +1540,7 @@ void ScriptingService::registerCustomAction(const QString &identifier,
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         MetricsService::instance()->sendVisitIfEnabled(
             QStringLiteral("scripting/") % QString(__func__));
 
@@ -1569,7 +1571,7 @@ void ScriptingService::registerLabel(const QString &identifier,
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         MetricsService::instance()->sendVisitIfEnabled(
             QStringLiteral("scripting/") % QString(__func__));
 
@@ -1592,7 +1594,7 @@ void ScriptingService::setLabelText(const QString &identifier,
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         MetricsService::instance()->sendVisitIfEnabled(
             QStringLiteral("scripting/") % QString(__func__));
 
@@ -1613,7 +1615,7 @@ void ScriptingService::createNote(QString text) {
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         MetricsService::instance()->sendVisitIfEnabled(
             QStringLiteral("scripting/") % QString(__func__));
 
@@ -1813,7 +1815,7 @@ void ScriptingService::setCurrentNote(NoteApi *note) {
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         mainWindow->setCurrentNoteFromNoteId(note->getId());
     }
 #else
@@ -1834,7 +1836,7 @@ void ScriptingService::informationMessageBox(const QString &text,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         QMessageBox::information(mainWindow, title, text);
     }
 #else
@@ -1863,7 +1865,7 @@ int ScriptingService::questionMessageBox(const QString &text,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         return QMessageBox::question(
             mainWindow, title, text, QMessageBox::StandardButtons(buttons),
             QMessageBox::StandardButton(defaultButton));
@@ -1894,7 +1896,7 @@ QString ScriptingService::getOpenFileName(const QString &caption,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         return QFileDialog::getOpenFileName(mainWindow, caption, dir, filter);
     }
 #else
@@ -1922,7 +1924,7 @@ QString ScriptingService::getSaveFileName(const QString &caption,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         return QFileDialog::getSaveFileName(mainWindow, caption, dir, filter);
     }
 #else
@@ -1983,7 +1985,7 @@ QStringList ScriptingService::selectedNotesPaths() {
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         Q_FOREACH (Note note, mainWindow->selectedNotes()) {
             selectedNotePaths
                 << QDir::toNativeSeparators(note.fullNoteFilePath());
@@ -2010,7 +2012,7 @@ QList<int> ScriptingService::selectedNotesIds() const {
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
 
-    if (mainWindow != Q_NULLPTR) {
+    if (mainWindow != nullptr) {
         Q_FOREACH (Note note, mainWindow->selectedNotes()) {
             selectedNotesIds << note.getId();
         }
@@ -2053,7 +2055,7 @@ QString ScriptingService::inputDialogGetItem(const QString &title,
         QStringLiteral("scripting/") % QString(__func__));
 
 #ifndef INTEGRATION_TESTS
-    return QInputDialog::getItem(Q_NULLPTR, title, label, items, current,
+    return QInputDialog::getItem(nullptr, title, label, items, current,
                                  editable);
 #else
     Q_UNUSED(title)
@@ -2080,7 +2082,7 @@ QString ScriptingService::inputDialogGetText(const QString &title,
         QStringLiteral("scripting/") % QString(__func__));
 
 #ifndef INTEGRATION_TESTS
-    return QInputDialog::getText(Q_NULLPTR, title, label, QLineEdit::Normal,
+    return QInputDialog::getText(nullptr, title, label, QLineEdit::Normal,
                                  text);
 #else
     Q_UNUSED(title)
@@ -2159,7 +2161,7 @@ bool ScriptingService::jumpToNoteSubFolder(const QString &noteSubFolderPath,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow == Q_NULLPTR) {
+    if (mainWindow == nullptr) {
         return false;
     }
 
@@ -2303,14 +2305,14 @@ void ScriptingService::triggerMenuAction(const QString &objectName,
 
 #ifndef INTEGRATION_TESTS
     MainWindow *mainWindow = MainWindow::instance();
-    if (mainWindow == Q_NULLPTR) {
+    if (mainWindow == nullptr) {
         return;
     }
 
     QAction *action = mainWindow->findAction(objectName);
 
     // return if action wasn't found
-    if (action == Q_NULLPTR) {
+    if (action == nullptr) {
         return;
     }
 
@@ -2410,3 +2412,31 @@ bool ScriptingService::clearCacheDir(const QString &subDir) const {
 
     return result;
 }
+
+/**
+ * Adds a highlighting rule to the syntax highlighter of the editor
+ *
+ * @param pattern {QString} the regular expression pattern to highlight
+ * @param shouldContain {QString} a string that must be contained in the highlighted text for the pattern to be parsed
+ * @param state {int} the state of the syntax highlighter to use
+ * @param capturingGroup {int} the capturing group for the pattern to use for highlighting (default: 0)
+ * @param maskedGroup {int} the capturing group for the pattern to use for masking (default: 0)
+ */
+void ScriptingService::addHighlightingRule(const QString &pattern,
+                                           const QString &shouldContain,
+                                           int state,
+                                           int capturingGroup,
+                                           int maskedGroup) {
+    QOwnNotesMarkdownHighlighter::ScriptingHighlightingRule rule(
+        static_cast<MarkdownHighlighter::HighlighterState>(state));
+    rule.pattern = QRegularExpression(pattern);
+    rule.shouldContain = shouldContain;
+    rule.capturingGroup = capturingGroup;
+    rule.maskedGroup = maskedGroup;
+    _highlightingRules.append(rule);
+}
+
+QVector<QOwnNotesMarkdownHighlighter::ScriptingHighlightingRule>
+ScriptingService::getHighlightingRules() {
+    return _highlightingRules;
+}
