@@ -19,6 +19,7 @@
 #include <QDebug>
 #include <QProcess>
 #include <QtCore/QSettings>
+#include <QStandardPaths>
 
 #include "gui.h"
 #include "misc.h"
@@ -41,13 +42,15 @@ void Utils::Git::commitCurrentNoteFolder() {
         return;
     }
 
+    const auto git = gitCommand();
+
     auto* process = new QProcess();
     process->setWorkingDirectory(NoteFolder::currentLocalPath());
 
-    if (!executeGitCommand(QStringList{"init"}, process) ||
-        !executeGitCommand(QStringList{"config", "commit.gpgsign", "false"}, process) ||
-        !executeGitCommand(QStringList{"add", "-A"}, process) ||
-        !executeGitCommand(QStringList{"commit", "-m", "QOwnNotes commit"}, process)) {
+    if (!executeGitCommand(git, QStringList{"init"}, process) ||
+        !executeGitCommand(git, QStringList{"config", "commit.gpgsign", "false"}, process) ||
+        !executeGitCommand(git, QStringList{"add", "-A"}, process) ||
+        !executeGitCommand(git, QStringList{"commit", "-m", "QOwnNotes commit"}, process)) {
     }
 
     delete (process);
@@ -62,7 +65,7 @@ void Utils::Git::commitCurrentNoteFolder() {
  */
 bool Utils::Git::executeCommand(const QString& command, const QStringList& arguments,
                                 QProcess* process, bool withErrorDialog) {
-    if (process == Q_NULLPTR) {
+    if (process == nullptr) {
         process = new QProcess();
     }
 
@@ -73,7 +76,7 @@ bool Utils::Git::executeCommand(const QString& command, const QStringList& argum
 
         if (withErrorDialog) {
             Utils::Gui::warning(
-                Q_NULLPTR, QObject::tr("Command failed!"),
+                nullptr, QObject::tr("Command failed!"),
                 QObject::tr("The command <code>%1</code> with arguments <code>%2</code> failed!")
                     .arg(command, arguments.join(QStringLiteral(", "))),
                 "command-failed");
@@ -105,9 +108,9 @@ bool Utils::Git::executeCommand(const QString& command, const QStringList& argum
  * @param process
  * @return
  */
-bool Utils::Git::executeGitCommand(const QStringList& arguments, QProcess* process,
+bool Utils::Git::executeGitCommand(const QString &gitExe, const QStringList& arguments, QProcess* process,
                                    bool withErrorDialog) {
-    return executeCommand(gitCommand(), arguments, process, withErrorDialog);
+    return executeCommand(gitExe, arguments, process, withErrorDialog);
 }
 
 /**
@@ -119,15 +122,24 @@ QString Utils::Git::gitCommand() {
     QSettings settings;
     QString path = settings.value("gitExecutablePath").toString();
 
-    if (path.isEmpty()) {
-#ifdef Q_OS_WIN
-        path = "git.exe";
-#else
-        path = "git";
-#endif
+    // ok, user defined path
+    if (!path.isEmpty()) {
+        return path;
     }
 
-    return path;
+#ifdef Q_OS_WIN
+    path = "git.exe"; // FIXME: is the ".exe" even needed? I don't think so
+#else
+    path = "git";
+#endif
+
+    // Ensure the "git" is from a standard path, and not a random exe named git
+    auto fullGitPath = QStandardPaths::findExecutable(path);
+    if (fullGitPath.isEmpty()) {
+        return {};
+    }
+
+    return fullGitPath;
 }
 
 /**
@@ -175,4 +187,4 @@ void Utils::Git::showLog(const QString& filePath) {
 
     Utils::Misc::startDetachedProcess(command, parameters,
                                       NoteFolder::currentLocalPath());
-}
\ No newline at end of file
+}
