@@ -152,11 +152,11 @@ void Utils::Misc::openFolderSelect(const QString &absolutePath) {
         openPath(path.left(path.lastIndexOf("/")));
     }
 #elif defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    if (QFileInfo(path).exists()) {
+    static const auto fullXdgMimePath = QStandardPaths::findExecutable(QStringLiteral("xdg-mime"));
+    if (!fullXdgMimePath.isEmpty() && QFileInfo(path).exists()) {
         QProcess proc;
         QString output;
-        proc.start(QStringLiteral("xdg-mime"),
-                   QStringList{"query", "default", "inode/directory"});
+        proc.start(fullXdgMimePath, QStringList{"query", "default", "inode/directory"});
         proc.waitForFinished();
         output = proc.readLine().simplified();
         if (output == QStringLiteral("dolphin.desktop") ||
@@ -564,7 +564,7 @@ void Utils::Misc::waitMsecs(int msecs) {
 QString Utils::Misc::portableDataPath() {
     QString path = QString();
 
-    if (qApp != Q_NULLPTR) {
+    if (qApp != nullptr) {
         // for AppImages we best take out the path directly from the first
         // argument of the executable arguments, because the applicationDirPath
         // will be some temporary path
@@ -837,7 +837,7 @@ QList<QObject *> Utils::Misc::getParents(QObject *object) {
     QList<QObject *> list;
     QObject *parent = object->parent();
 
-    if (parent != Q_NULLPTR) {
+    if (parent != nullptr) {
         list = getParents(parent);
         list << parent;
     }
@@ -1016,9 +1016,11 @@ QByteArray Utils::Misc::downloadUrl(const QUrl &url, bool usePost, QByteArray po
     networkRequest.setHeader(QNetworkRequest::UserAgentHeader,
                              Utils::Misc::friendlyUserAgentString());
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+#if QT_VERSION < QT_VERSION_CHECK(5, 9, 0)
     networkRequest.setAttribute(QNetworkRequest::FollowRedirectsAttribute,
                                 true);
+#else
+    networkRequest.setAttribute(QNetworkRequest::RedirectPolicyAttribute, true);
 #endif
 
     QByteArray data;
@@ -1541,11 +1543,7 @@ QString Utils::Misc::htmlspecialchars(QString text) {
  * @param text
  */
 void Utils::Misc::printInfo(const QString &text) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
     qInfo() << text;
-#else
-    printf("%s\n", text.toLatin1().data());
-#endif
 }
 
 /**
@@ -2016,7 +2014,7 @@ QString Utils::Misc::generateDebugInformation(bool withGitHubLineBreaks) {
 bool Utils::Misc::regExpInListMatches(const QString &text,
                                       const QStringList &regExpList) {
     for (const QString &regExp : regExpList) {
-        const QString &trimmed = regExp.trimmed();
+        const QString trimmed = regExp.trimmed();
         if (trimmed.isEmpty()) {
             continue;
         }
@@ -2429,12 +2427,14 @@ void Utils::Misc::switchToLightMode() {
     switchToDarkOrLightMode(false);
 }
 
-void Utils::Misc::transformEvernoteImportText(QString &content, bool withCleanup) {
+void Utils::Misc::unescapeEvernoteImportText(QString &content) {
     content.replace(QStringLiteral("\\\""), QStringLiteral("\""));
 
     // decode HTML entities
     content = Utils::Misc::unescapeHtml(std::move(content));
+}
 
+void Utils::Misc::transformEvernoteImportText(QString &content, bool withCleanup) {
     // add a newline in front of lists
     //            content.replace(QRegularExpression("<ul.*?>"),
     //            "\n<ul>");
@@ -2511,10 +2511,16 @@ QString Utils::Misc::testEvernoteImportText(const QString& data) {
     // content seems to be html encoded
     query.evaluateTo(&content);
 
+    // unescape content
+    Utils::Misc::unescapeEvernoteImportText(content);
+
     Utils::Misc::transformEvernoteImportText(content, true);
 
     return content.trimmed();
 #endif
+    qWarning() << Q_FUNC_INFO << "not implemented for qt6";
+    Q_UNUSED(data);
+    return {};
 }
 
 /**
@@ -2558,11 +2564,9 @@ QString Utils::Misc::logMsgTypeText(QtMsgType logType) {
         case QtMsgType::QtDebugMsg:
             type = QStringLiteral("Debug");
             break;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 5, 0))
         case QtMsgType::QtInfoMsg:
             type = QStringLiteral("Info");
             break;
-#endif
         case QtMsgType::QtWarningMsg:
             type = QStringLiteral("Warning");
             break;
@@ -2619,7 +2623,7 @@ int levenshteinDistance(const QString &source, const QString &target)
     for (int i = 0; i < sourceCount; i++) {
         column[0] = i + 1;
         for (int j = 0; j < targetCount; j++) {
-            column[j + 1] = std::min({
+            column[j + 1] = std::min<int>({
                 1 + column.at(j),
                 1 + previousColumn.at(1 + j),
                 previousColumn.at(j) + ((source.at(i) == target.at(j)) ? 0 : 1)
@@ -2654,10 +2658,11 @@ bool Utils::Misc::isSimilar(const QString &str1, const QString &str2, int thresh
         return true;
     }
 
-    // Use levenshtein if the middle part of the strings is different
-    if (levenshteinDistance(str1, str2) <= threshold) {
-        return true;
-    }
+    // Use levenshtein for not too large notes if the middle part of the strings is different
+    // Disabled, because it takes far too long!
+//    if ((str1.length() < 5000) && (levenshteinDistance(str1, str2) <= threshold)) {
+//        return true;
+//    }
 
     if (str1.length() != str2.length()) {
         return false;
@@ -2730,3 +2735,7 @@ QString Utils::Misc::createAbsolutePathsInHtml(const QString &html, const QStrin
 
     return result;
 }
+
+int Utils::Misc::getPreviewRefreshDebounceTime() {
+    return QSettings().value(QStringLiteral("MainWindow/noteTextView.refreshDebounceTime"), 600).toInt();
+}
