@@ -159,6 +159,7 @@ QLatin1String platform();
 void switchToDarkOrLightMode(bool darkMode);
 void switchToDarkMode();
 void switchToLightMode();
+void unescapeEvernoteImportText(QString &content);
 void transformEvernoteImportText(QString &content, bool withCleanup = false);
 void cleanupEvernoteImportText(QString &content);
 QString testEvernoteImportText(const QString& data);
@@ -167,6 +168,7 @@ QString logMsgTypeText(QtMsgType logType);
 bool isSimilar(const QString &str1, const QString &str2, int threshold = 3);
 QString getBaseUrlFromUrlString(const QString &urlString, bool withBasePath = false);
 QString createAbsolutePathsInHtml(const QString &html, const QString &url);
+int getPreviewRefreshDebounceTime();
 }    // namespace Misc
 }    // namespace Utils
 
