@@ -34,15 +34,14 @@ class LogWidget : public QFrame {
         StatusLogType,
         ScriptingLogType
     };
+    Q_ENUM(LogType);
 
     explicit LogWidget(QWidget *parent = 0);
     ~LogWidget();
-    static LogWidget *instance();
-    static LogWidget *createInstance(QWidget *parent);
     static void logMessageOutput(QtMsgType type,
                                  const QMessageLogContext &context,
                                  const QString &msg);
-    bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject *obj, QEvent *event) override;
     QString getLogText() const;
 
    public slots:
@@ -55,8 +54,6 @@ class LogWidget : public QFrame {
 
     void on_logTextEdit_customContextMenuRequested(QPoint pos);
 
-    void onDestroyed(QObject *obj = Q_NULLPTR);
-
    private:
     Ui::LogWidget *ui;
 
