@@ -35,26 +35,30 @@ class NavigationWidget : public QTreeWidget {
 
    public:
     explicit NavigationWidget(QWidget *parent = 0);
-    ~NavigationWidget();
 
-    void parse(const QTextDocument *document);
-    void setDocument(const QTextDocument *document);
+    void parse(const QTextDocument *document, int textCursorPosition);
     static QVector<Node> parseDocument(const QTextDocument *const document);
 
+    void selectItemForCursorPosition(int position);
+
    private slots:
     void onCurrentItemChanged(QTreeWidgetItem *current,
                               QTreeWidgetItem *previous);
     void onItemClicked(QTreeWidgetItem *current, int column);
-    void onParseCompleted();
+
+   private:
+    void buildNavTree(const QVector<Node> &nodes);
+    void doParse();
 
    signals:
     void positionClicked(int position);
 
    private:
-    const QTextDocument *_document;
+    const QTextDocument *_doc;
     QHash<int, QTreeWidgetItem *> _lastHeadingItemList;
-    QFutureWatcher<QVector<Node>> *_parseFutureWatcher;
     QVector<Node> _navigationTreeNodes;
+    int _cursorPosition;
 
     QTreeWidgetItem *findSuitableParentItem(int elementType) const;
+    int findItemIndexforCursorPosition(int position) const;
 };
